# Installation

Run `composer require require dedi/sylius-migration-plugin`

Add plugin class to your `config/bundles.php`:

```php
<?php
$bundles = [
    // ...
    Dedi\SyliusMigrationPlugin\DediSyliusMigrationPlugin::class => ['all' => true],
    // ...
];
```

Import de configuration in `config/packages/_sylius.yaml` file 

```yaml
    imports:
        - { resource: "@DediSyliusMigrationPlugin/Resources/config/app/config.yaml" }    
```

Configure the plugin with the mandatory parameters (see the [configuration documentation](CONFIG.md) for more info on configuration capabilities)

```yaml
dedi_sylius_migration:
  config:
      legacy_site_url: ''
      new_site_url: ''
      legacy_site_media_path: ''
```

# Setting the database up

You do not need to set up a destination database as this is likely to be the default database configured for your project. If you wish to use another database, the database setup steps are the same.

On a Satisfactory installation, the quickest way to set up the source database is to add a new MySQL container to your `docker-compose.yml` file

```yaml
services:
    php:
        depends_on:
            - legacy_mysql
            - mysql
            - selenium-hub
            
    legacy_mysql:
        image: mysql:5.7
        environment:
            - MYSQL_ROOT_PASSWORD=${MYSQL_ROOT_PASSWORD:-nopassword}
            - MYSQL_DATABASE=${DATABASE_NAME:-sylius}
            - MYSQL_USER=${DATABASE_USER:-sylius}
            - MYSQL_PASSWORD=${MYSQL_PASSWORD:-nopassword}
        ports:
          - 3307:3306
        volumes:
          - ./.docker/mysql/dump:/docker-entrypoint-initdb.d:ro
```

Add the legacy database dump.sql file in the `.docker/mysql/dump` directory and start the project : the database will be automatically loaded.

With this setup, the source database url will be : `DATABASE_URL=mysql://DATABASE_USER:MYSQL_PASSWORD@legacy_mysql/DATABASE_NAME`

Next, configure the source and destination connections in your `.env.local` file :

```text
MIGRATION_SOURCE_DATABASE_URL=...
MIGRATION_DEST_DATABASE_URL=...
```

You can also use the `.env.local` optional variables to override some configuration parameters (here are the default values) :

```text
MIGRATION_SOURCE_DRIVER= 'pdo_mysql'
MIGRATION_SOURCE_SERVER_VERSION= '5.7'
MIGRATION_SOURCE_CHARSET= 'utf8mb4'

MIGRATION_DEST_DRIVER= 'pdo_mysql'
MIGRATION_DEST_SERVER_VERSION= '5.7'
MIGRATION_DEST_CHARSET= 'utf8mb4'
```

Finally, check that the connection is up and running

```bash
php bin/console dedi:migrate-sql:check
```

You can know configure your mapping and run the import

```bash
php bin/console dedi:migrate-sql:execute
```

# Aditional notes

Check out the [configuration documentation](CONFIG.md) for more in depth information about the general plugin configuration

Check out the [mapping documentation](MAPPING.md) for more in depth information about mapping configuration 

Check out the [actions documentation](ACTION.md) for more in depth information about migration actions

Check out the [transformers documentation](TRANSFORMER.md) for more in depth information about data transformers
